@@ -423,28 +423,29 @@ class ColorHandler(logging.Handler):
         finally:
             self.release()
 
-    def __display_with_backgroud_color(self,record):
+    def __display_with_backgroud_color(self,record:logging.LogRecord):
         try:
             # very_nb_print(record)
+            effective_information_msg = record.msg
+            record.msg = ''
             msg = self.format(record)
             stream = self.stream
-            msg1, msg2 = self.__spilt_msg(record.levelno, msg)
             if record.levelno == 10:
                 # msg_color = ('\033[0;32m%s\033[0m' % msg)  # 绿色
                 # print(msg1)
-                msg_color = f'\033[0;32m{msg1}\033[0m \033[0;{self._word_color};42m{msg2}\033[0m'  # 绿色
+                msg_color = f'\033[0;32m{msg}\033[0m \033[0;{self._word_color};42m{effective_information_msg}\033[0m'  # 绿色
             elif record.levelno == 20:
                 # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.bule, msg))  # 青蓝色 36    96
-                msg_color = f'\033[0;36m{msg1}\033[0m \033[0;{self._word_color};46m{msg2}\033[0m'
+                msg_color = f'\033[0;36m{msg}\033[0m \033[0;{self._word_color};46m{effective_information_msg}\033[0m'
             elif record.levelno == 30:
                 # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.yellow, msg))
-                msg_color = f'\033[0;33m{msg1}\033[0m \033[0;{self._word_color};43m{msg2}\033[0m'
+                msg_color = f'\033[0;33m{msg}\033[0m \033[0;{self._word_color};43m{effective_information_msg}\033[0m'
             elif record.levelno == 40:
                 # msg_color = ('\033[%s;35m%s\033[0m' % (self._display_method, msg))  # 紫红色
-                msg_color = f'\033[0;35m{msg1}\033[0m \033[0;{self._word_color};45m{msg2}\033[0m'
+                msg_color = f'\033[0;35m{msg}\033[0m \033[0;{self._word_color};45m{effective_information_msg}\033[0m'
             elif record.levelno == 50:
                 # msg_color = ('\033[%s;31m%s\033[0m' % (self._display_method, msg))  # 血红色
-                msg_color = f'\033[0;31m{msg1}\033[0m \033[0;{self._word_color};41m{msg2}\033[0m'
+                msg_color = f'\033[0;31m{msg}\033[0m \033[0;{self._word_color};41m{effective_information_msg}\033[0m'
             else:
                 msg_color = msg
             # print(msg_color,'***************')
@@ -456,28 +457,30 @@ class ColorHandler(logging.Handler):
             very_nb_print(traceback.format_exc())
             # self.handleError(record)
 
-    def __display_with_no_backgroud_color(self, record):
+    def __display_with_no_backgroud_color(self, record:logging.LogRecord):
         try:
             # very_nb_print(record)
+            effective_information_msg = record.msg
+            record.msg=''
             msg = self.format(record)
             stream = self.stream
-            msg1, msg2 = self.__spilt_msg(record.levelno, msg)
+            # msg1, msg2 = self.__spilt_msg(record.levelno, msg)
             if record.levelno == 10:
                 # msg_color = ('\033[0;32m%s\033[0m' % msg)  # 绿色
                 # print(msg1)
-                msg_color = f'\033[0;32m{msg1} {msg2}\033[0m'  # 绿色
+                msg_color = f'\033[0;32m{msg} {effective_information_msg}\033[0m'  # 绿色
             elif record.levelno == 20:
                 # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.bule, msg))  # 青蓝色 36    96
-                msg_color = f'\033[0;36m{msg1} {msg2}\033[0m'
+                msg_color = f'\033[0;36m{msg} {effective_information_msg}\033[0m'
             elif record.levelno == 30:
                 # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.yellow, msg))
-                msg_color = f'\033[0;33m{msg1} {msg2}\033[0m'
+                msg_color = f'\033[0;33m{msg} {effective_information_msg}\033[0m'
             elif record.levelno == 40:
                 # msg_color = ('\033[%s;35m%s\033[0m' % (self._display_method, msg))  # 紫红色
-                msg_color = f'\033[0;35m{msg1} {msg2}\033[0m'
+                msg_color = f'\033[0;35m{msg} {effective_information_msg}\033[0m'
             elif record.levelno == 50:
                 # msg_color = ('\033[%s;31m%s\033[0m' % (self._display_method, msg))  # 血红色
-                msg_color = f'\033[0;31m{msg1} {msg2}\033[0m'
+                msg_color = f'\033[0;31m{msg} {effective_information_msg}\033[0m'
             else:
                 msg_color = msg
             # print(msg_color,'***************')
